==> libggi_1.99.2.0b2.1.orig.tar.gz: libggi-2.0b2.1/default/planar/visual.c <==
/* $Id: visual.c,v 1.9 1999/03/23 00:13:29 marcus Exp $
******************************************************************************

  Planar graphics library.

  Copyright (C) 1998 Andrew Apted  [andrew@ggi-project.org]

   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************************
*/

#include "pllib.h"


int GGIdlinit(ggi_visual *vis, const char *version,void *argptr)
{
	/* Frame handling
	 */
	vis->opdraw->setreadframe	= _ggi_default_setreadframe;
	vis->opdraw->setwriteframe	= _ggi_default_setwriteframe;
	
	/* Generic drawing
	 */
	if (vis->needidleaccel) {
		vis->opdraw->putpixel_nc	= GGI_pl_putpixel_nca;
		vis->opdraw->getpixel		= GGI_pl_getpixela;
	} else {
		vis->opdraw->putpixel_nc	= GGI_pl_putpixel_nc;
		vis->opdraw->getpixel		= GGI_pl_getpixel;
	}

	return GGI_DL_OPDRAW;
}

int GGIdlcleanup(ggi_visual *vis)
{
	return 0;
}
		
#include <ggi/internal/ggidlinit.h>

==> libggi-2.0b1.tar.gz: libggi-2.0b1/default/planar/visual.c <==
/* $Id: visual.c,v 1.8 1998/12/09 04:27:27 marcus Exp $
******************************************************************************

  Planar graphics library.

  Copyright (C) 1998 Andrew Apted  [andrew@ggi-project.org]

   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************************
*/

#include <ggi/internal/ggi-dl.h>


int GGIdlinit(ggi_visual *vis, const char *version,void *argptr)
{
	/* Frame handling
	 */

	vis->opdraw->setreadframe = _ggi_default_setreadframe;
	vis->opdraw->setwriteframe = _ggi_default_setwriteframe;
	
	/* Generic drawing
	 */
	vis->opdraw->putpixel_nc=GGIputpixel_nc;
	vis->opdraw->getpixel=GGIgetpixel;

	/* Not yet implemented:
	 *	drawpixel_nc, drawpixel, putpixel,
	 *	putc, getcharsize,
	 *	drawhline_nc, drawvline_nc,
	 *	puthline, putvline,
	 *	gethline, getvline.
	 */

	/* Left to generic-color:
	 *    mapcolor, unmappixel,
	 *    packcolors, unpackpixels.
	 */

	/* Left to generic-stubs:
	 *    drawhline, drawvline, drawline,
	 *    puts, copybox, crossblit.
	 */

	return GGI_DL_OPDRAW;
}

int GGIdlcleanup(ggi_visual *vis)
{
	return 0;
}
		
#include <ggi/internal/ggidlinit.h>
